/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package example.filesystem;

import example.filesystem.backend.FileSystem;
import example.filesystem.backend.UnixFileSystem;
import example.filesystem.callback.BackupFrequencyCallback;
import example.filesystem.callback.CommentCallback;
import example.filesystem.callback.FsckPassNumberCallback;
import example.filesystem.callback.MountPointCallback;
import example.filesystem.callback.OptionsCallback;
import org.apache.ws.resource.example.filesystem.BackupFrequencyDocument;
import org.apache.ws.resource.example.filesystem.CommentDocument;
import org.apache.ws.resource.example.filesystem.DeviceSpecialFileDocument;
import org.apache.ws.resource.example.filesystem.FileSystemPropertiesDocument;
import org.apache.ws.resource.example.filesystem.FsckPassNumberDocument;
import org.apache.ws.resource.example.filesystem.MountPointDirectoryDocument;
import org.apache.ws.resource.example.filesystem.OptionsDocument;
import org.apache.ws.resource.example.filesystem.TypeDocument;
import org.apache.ws.resource.properties.ResourceProperty;

import java.util.List;

/**
 * A filesystem WS-Resource.
 * <p/>
 * NOTE: This class is generated.
 *
 * @author Ian P. Springer
 * @author Sal Campana
 */
public class FileSystemResource extends AbstractFileSystemResource

{
    /**
     * This bean represents the "backend" managed resource for this WS-Resource.
     */
    private FileSystem m_fileSystem;

    /**
     * DOCUMENT_ME
     */
    public void init()
    {

        super.init();

        /*
         * This is where you should associate the backend instance with
         * the resource instance for a given id.
         */
        m_fileSystem = new UnixFileSystem( m_id );

        /*
         * Initialize each of our properties by calling prop.add(propElem) and/or prop.setCallback(callback)...
         */
        ResourceProperty prop = m_propSet.get( FileSystemPropertyQNames.DEVICE_SPECIAL_FILE );
        DeviceSpecialFileDocument deviceDocXBean = DeviceSpecialFileDocument.Factory.newInstance();
        deviceDocXBean.setDeviceSpecialFile( m_fileSystem.getDeviceSpecialFile() );
        prop.add( deviceDocXBean );

        prop = m_propSet.get( FileSystemPropertyQNames.TYPE );
        TypeDocument typeDocXBean = TypeDocument.Factory.newInstance();
        typeDocXBean.setType( m_fileSystem.getType() );
        prop.add( typeDocXBean );

        BackupFrequencyDocument backupDocXBean = BackupFrequencyDocument.Factory.newInstance();
        backupDocXBean.setBackupFrequency( m_fileSystem.getBackupFrequency() );
        prop = m_propSet.get( FileSystemPropertyQNames.BACKUP_FREQUENCY );
        prop.add( backupDocXBean );
        prop.setCallback( new BackupFrequencyCallback( m_fileSystem ) );

        CommentDocument commentDocXBean = CommentDocument.Factory.newInstance();
        commentDocXBean.setComment( m_fileSystem.getComment() );
        prop = m_propSet.get( FileSystemPropertyQNames.COMMENT );
        prop.add( commentDocXBean );
        prop.setCallback( new CommentCallback( m_fileSystem ) );

        FsckPassNumberDocument fsckDocXBean = FsckPassNumberDocument.Factory.newInstance();
        fsckDocXBean.setFsckPassNumber( m_fileSystem.getFsckPassNumber() );
        prop = m_propSet.get( FileSystemPropertyQNames.FSCK_PASS_NUMBER );
        prop.add( fsckDocXBean );
        prop.setCallback( new FsckPassNumberCallback( m_fileSystem ) );

        MountPointDirectoryDocument mountPointDocXBean = MountPointDirectoryDocument.Factory.newInstance();
        mountPointDocXBean.setMountPointDirectory( m_fileSystem.getMountPoint() );
        prop = m_propSet.get( FileSystemPropertyQNames.MOUNT_POINT_DIR );
        prop.add( mountPointDocXBean );
        prop.setCallback( new MountPointCallback( m_fileSystem ) );

        OptionsDocument optionsDocXBean =
                OptionsDocument.Factory.newInstance();
        org.apache.ws.resource.example.filesystem.OptionsDocument.Options options =
                optionsDocXBean.addNewOptions();
        List backendOptions =
                m_fileSystem.getOptions();
        for ( int i = 0; i < backendOptions.size(); i++ )
        {
            options.addOption( (String) backendOptions.get( i ) );
        }

        prop = m_propSet.get( FileSystemPropertyQNames.OPTIONS );
        prop.add( optionsDocXBean );
        prop.setCallback( new OptionsCallback( m_fileSystem ) );

    }

}